organization

# XMLRésuméLibrary: User Guide

objective | Element Reference | pageNums

## Name

organization — A name of an organization

## Synopsis

### Content Model

    (#PCDATA|emphasis|citation|url|link)*

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `organization` element contains the name of a professional or other type of organization.

### Parents

`organization` may be contained in these elements: `award`, `clearance`, `membership`, `referee`

### Attributes

`id`

  A string used to uniquely identify an organization. The organization may then be referred to by this identifier.

## See Also

`institution`.

-->

## Examples

    <membership>
      <organization>Croquet Players' Association of the UK</organization>
    </membership>

objective | Element Reference | pageNums